@@ -543,12 +543,12 @@ as_gt.gs_design <- function(x,
       gt::tab_footnote(
         footnote = paste0(
           "Cumulative alpha for final analysis (", x_alpha,
-          ") is less than the full alpha (0.025) when
+          ") is less than the full alpha (", full_alpha, ") when
           the futility bound is non-binding. ",
           "The smaller value subtracts the probability of
           crossing a futility bound before ",
           " crossing an efficacy bound at
-          a later analysis (0.025 - ",
+          a later analysis (", full_alpha, " - ",
           full_alpha - x_alpha, " = ", x_alpha,
           ") under the null hypothesis."
         ),
